import {
  defaultCreateLoggerOptions,
} from './defaultCreateLoggerOptions';

export const createLogger = ({
  colorFormatting,
  levels,
  loggerFunctions,
} = defaultCreateLoggerOptions) => {
  // None leaves this as-is.
  let levelsMap = {
    error: () => {},
    log: () => {},
    warn: () => {},
  };

  if (levels) {
    const formattedLevels = Array.from(levels).map((level) => {
      return level.trim().toLowerCase();
    });

    for (const level of formattedLevels) {
      if (level === 'none') {
        return levelsMap = {};
      } else if (level === 'error') {
        levelsMap.error = loggerFunctions.error;
      } else if (level === 'log') {
        levelsMap.log = loggerFunctions.log;
      } else if (level === 'warn') {
        levelsMap.warn = loggerFunctions.warn;
      }
    }
  }

  const logTypes = [ 'error', 'log', 'warn' ];
  for (logType of logTypes) {
    if (logType in levelsMap) {
      levelsMap[logType] = levelsMap[logType].bind(
        null,
        colorFormatting[logType][0],
      );
    } else {
      levelsMap[logType] = levelsMap[logType].bind(
        null,
        colorFormatting[logType][1],
      );
    }
  }
};
